@@ -26,6 +26,7 @@ class ZephyrFormatter(Formatter):
     json_scalar_types = json_number_types + (six.text_type, bool, type(None))
     file = None
     step_count = 0
+    
 
     def __init__(self, stream_opener, config):
         super(ZephyrFormatter, self).__init__(stream_opener, config)
@@ -36,6 +37,7 @@ class ZephyrFormatter(Formatter):
         self.current_scenario = None
         self._step_index = 0
         self.step_count = 0
+        self.str_result_json=""
 
     def reset(self):
         self.current_feature = None
@@ -50,7 +52,7 @@ class ZephyrFormatter(Formatter):
 
     def feature(self, feature):
         self.file_cleanup(False, "tmp.json")
-        self.open_new_stream()
+        self.open_new_file()
         self.reset()
         self.current_feature = feature
         self.current_feature_data = {
@@ -203,9 +205,9 @@ class ZephyrFormatter(Formatter):
         self.write_feature_results()
         self.reset()
 
-    def open_new_stream(self):
-        self.stream = self.open()
+    def open_new_file(self):
         self.file = open(f"{self.results_dir}/tmp.json", "w")
+        
 
     def close(self):
         if self.feature_count == 0:
@@ -241,17 +243,19 @@ class ZephyrFormatter(Formatter):
     # -- JSON-WRITER:
     def write_json_header(self):
         self.file.write("[")
+        self.file.flush()
 
     def write_json_footer(self):
         self.file.write("]")
         self.file.flush()
 
     def write_json_feature(self, feature_data):
-        self.file.write(json.dumps(feature_data, **self.dumps_kwargs))
+        self.file.write(json.dumps(feature_data))
         self.file.flush()
 
     def write_json_feature_separator(self):
         self.file.write(",\n\n")
+        self.file.flush()
 
     # -- File functions:
 
@@ -262,7 +266,7 @@ class ZephyrFormatter(Formatter):
             elif file_name == name:
                 os.remove(f"{self.results_dir}/{file_name}")
                 break
-            elif file_name.endswith(".json"):
+            elif file_name.endswith(".json") and file_name == name:
                 os.remove(f"{self.results_dir}/{file_name}")
 
     def zip_files(self):
@@ -291,6 +295,10 @@ class ZephyrFormatter(Formatter):
         with open(f"{self.results_dir}/tmp.json", "r") as f:
             content = json.load(f)
             zephyr_json = behave2cucumberZephyr.convert(content)
+            f.close()
 
-        with open(f"{self.results_dir}/{tag}.json", "w") as f:
-            json.dump(zephyr_json, f)
+        file_name = f"{self.results_dir}/{tag}.json"
+
+        with open(file_name, "w") as f:
+            # json.dump(zephyr_json, f)
+            f.write(json.dumps(zephyr_json))
\ No newline at end of file
